==> vst3sdk-docs-3.7.10_build_14-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/vstpresetfile_8h.js <==
var vstpresetfile_8h =
[
    [ "Entry", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry" ],
    [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", "classSteinberg_1_1Vst_1_1FileStream" ],
    [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", "classSteinberg_1_1Vst_1_1ReadOnlyBStream" ],
    [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", "classSteinberg_1_1Vst_1_1BufferStream" ],
    [ "ChunkID", "vstpresetfile_8h.html#adaf388baf0aebf53f3a12e1055fbd7ec", null ],
    [ "ChunkType", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6d", [
      [ "kHeader", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da247a9a25a5fcf2b9a22b25874fdbb32b", null ],
      [ "kComponentState", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da847efe92e412b647b41977961910049d", null ],
      [ "kControllerState", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da714cee5be2553879ce58605d04b77319", null ],
      [ "kProgramData", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da6f13cbddc9f9d7754192b09f424abfb0", null ],
      [ "kMetaInfo", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6dade0a9c73b08ec63caa0c8dbef1a4244b", null ],
      [ "kChunkList", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da676f1a84ce41206b756a3baa743bb968", null ],
      [ "kNumPresetChunks", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6daf4670cf4bdaa52d4168191c2bfb1ac6b", null ]
    ] ],
    [ "getChunkID", "vstpresetfile_8h.html#aecb30226876947afe7079bc185597f0c", null ],
    [ "isEqualID", "vstpresetfile_8h.html#a235c00ee8509a0532c542fc91326849b", null ]
];

==> vst3sdk-docs-3.7.12_build_20-1-any.pkg.tar.xz: usr/share/doc/vst3sdk-docs/vstsdk/vstpresetfile_8h.js <==
var vstpresetfile_8h =
[
    [ "PresetFile::Entry", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry.html", "structSteinberg_1_1Vst_1_1PresetFile_1_1Entry" ],
    [ "FileStream", "classSteinberg_1_1Vst_1_1FileStream.html", "classSteinberg_1_1Vst_1_1FileStream" ],
    [ "ReadOnlyBStream", "classSteinberg_1_1Vst_1_1ReadOnlyBStream.html", "classSteinberg_1_1Vst_1_1ReadOnlyBStream" ],
    [ "BufferStream", "classSteinberg_1_1Vst_1_1BufferStream.html", "classSteinberg_1_1Vst_1_1BufferStream" ],
    [ "ChunkID", "vstpresetfile_8h.html#adaf388baf0aebf53f3a12e1055fbd7ec", null ],
    [ "ChunkType", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6d", [
      [ "kHeader", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da247a9a25a5fcf2b9a22b25874fdbb32b", null ],
      [ "kComponentState", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da847efe92e412b647b41977961910049d", null ],
      [ "kControllerState", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da714cee5be2553879ce58605d04b77319", null ],
      [ "kProgramData", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da6f13cbddc9f9d7754192b09f424abfb0", null ],
      [ "kMetaInfo", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6dade0a9c73b08ec63caa0c8dbef1a4244b", null ],
      [ "kChunkList", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6da676f1a84ce41206b756a3baa743bb968", null ],
      [ "kNumPresetChunks", "vstpresetfile_8h.html#a6742d03aa1e93ba39b234d0ea402ee6daf4670cf4bdaa52d4168191c2bfb1ac6b", null ]
    ] ],
    [ "getChunkID", "vstpresetfile_8h.html#aecb30226876947afe7079bc185597f0c", null ],
    [ "isEqualID", "vstpresetfile_8h.html#a235c00ee8509a0532c542fc91326849b", null ]
];
